#!/usr/bin/python
# encoding: utf-8
"""
========================图片智能修复========================
"""
import requests
import json
import base64
import hashlib


class Idphoto:
    def __init__(self, appcode, timeout=7):
        self.appcode = appcode
        self.timeout = timeout

        self.repair_image_url = 'https://repair.market.alicloudapi.com/repair/image'  # 智能修复

        self.headers = {
            'Authorization': 'APPCODE ' + appcode,
        }

    def get_md5_data(self, body):
        """
        md5加密
        :param body_json:
        :return:
        """

        md5lib = hashlib.md5()
        md5lib.update(body.encode("utf-8"))
        body_md5 = md5lib.digest()
        body_md5 = base64.b64encode(body_md5)
        return body_md5

    def get_photo_base64(self, file_path):
        with open(file_path, 'rb') as fp:
            photo_base64 = base64.b64encode(fp.read())

        photo_base64 = photo_base64.decode('utf8')
        return photo_base64

    def aiseg_request(self, url, data, headers):
        resp = requests.post(url=url, data=data, headers=headers, timeout=self.timeout)
        res = {"status_code": resp.status_code}
        try:
            res["data"] = json.loads(resp.text)
            return res
        except Exception as e:
            print(e)

    def repair_image(self, file_path, mask_path):
        """
        证件照智能修复
        :return:
        """
        img_photo_base64 = self.get_photo_base64(file_path)
        mask_photo_base64 = self.get_photo_base64(mask_path)

        data = {
            'mask': mask_photo_base64,
            'image': img_photo_base64
        }
        body = json.dumps(data)
        body_md5 = self.get_md5_data(body=body)
        self.headers.update({'Content-MD5': body_md5})

        data = self.aiseg_request(url=self.repair_image_url, data=body, headers=self.headers)
        return data


if __name__ == "__main__":
    idphoto = Idphoto(appcode="你的appcode")

    d = idphoto.repair_image("1_repair.jpg", "mask.jpg")
    print(d)
